package com.qmth.eds.api;


import com.qmth.boot.api.constant.ApiConstant;
import com.qmth.eds.bean.dto.syssetting.SettingObject;
import com.qmth.eds.bean.result.EditResult;
import com.qmth.eds.common.contant.SystemConstant;
import com.qmth.eds.common.util.Result;
import com.qmth.eds.common.util.ResultUtil;
import com.qmth.eds.service.ExamAssignService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.validation.constraints.Max;
import javax.validation.constraints.Min;
import java.util.List;

/**
 * <p>
 * 赋分管理 前端控制器
 * </p>
 */
@Api(tags = "赋分管理controller")
@RestController
@RequestMapping(ApiConstant.DEFAULT_URI_PREFIX + "/assign")
@Validated
public class ExamAssignController {

    @Resource
    private ExamAssignService examAssignService;

    @ApiOperation(value = "分页查询")
    @PostMapping("/page")
    @ApiResponses({@ApiResponse(code = 200, message = "查询成功", response = Result.class)})
    public Result pageData(@RequestParam(value = "semesterId", required = false) Long semesterId,
                           @RequestParam(value = "examTypeId", required = false) Long examTypeId,
                           @RequestParam(value = "courseCode", required = false) String courseCode,
                           @RequestParam @Min(SystemConstant.PAGE_NUMBER_MIN) Integer pageNumber,
                           @RequestParam @Min(SystemConstant.PAGE_SIZE_MIN) @Max(SystemConstant.PAGE_SIZE_MAX) Integer pageSize) {
        return ResultUtil.ok(examAssignService.pageData(semesterId, examTypeId, courseCode, pageNumber, pageSize));
    }

    @ApiOperation(value = "准备试算")
    @PostMapping("/to_calc")
    @ApiResponses({@ApiResponse(code = 200, message = "查询成功", response = Result.class)})
    public Result toCalc(@RequestParam(value = "semesterId", required = false) Long semesterId,
                           @RequestParam(value = "examTypeId", required = false) Long examTypeId,
                           @RequestParam(value = "courseCode", required = false) String courseCode) {
        return ResultUtil.ok(examAssignService.toCalc(semesterId, examTypeId, courseCode));
    }


    @ApiOperation(value = "计算")
    @PostMapping("/calc")
    @ApiResponses({@ApiResponse(code = 200, message = "保存/更新成功", response = EditResult.class)})
    public Result save(@RequestParam(value = "semesterId", required = false) Long semesterId,
                       @RequestParam(value = "examTypeId", required = false) Long examTypeId,
                       @RequestParam(value = "courseCode", required = false) String courseCode,
                       @RequestParam(value = "courseName", required = false) String courseName,
                       @RequestParam(value = "formula", required = false) String formula,
                       @RequestParam(value = "fullScore", required = false) Double fullScore,
                       @RequestParam(value = "passScore", required = false) Double passScore,
                       @RequestParam(value = "coefficient", required = false) String coefficient) {
        return ResultUtil.ok(examAssignService.calcData(semesterId, examTypeId, courseCode, courseName, formula, fullScore, passScore, coefficient));
    }

    @ApiOperation(value = "计算结果查询")
    @PostMapping("/result")
    @ApiResponses({@ApiResponse(code = 200, message = "保存/更新成功", response = EditResult.class)})
    public Result result(@RequestParam(value = "semesterId", required = false) Long semesterId,
                         @RequestParam(value = "examTypeId", required = false) Long examTypeId,
                         @RequestParam(value = "courseCode", required = false) String courseCode,
                         @RequestParam(value = "courseName", required = false) String courseName,
                         @RequestParam(value = "formula", required = false) String formula,
                         @RequestParam @Min(SystemConstant.PAGE_NUMBER_MIN) Integer pageNumber,
                         @RequestParam @Min(SystemConstant.PAGE_SIZE_MIN) @Max(SystemConstant.PAGE_SIZE_MAX) Integer pageSize) {
        return ResultUtil.ok(examAssignService.result(semesterId, examTypeId, courseCode, courseName, formula, pageNumber, pageSize));
    }

    @ApiOperation(value = "计算结果对比")
    @PostMapping("/contrast")
    @ApiResponses({@ApiResponse(code = 200, message = "保存/更新成功", response = EditResult.class)})
    public Result contrast(@RequestParam(value = "semesterId", required = false) Long semesterId,
                           @RequestParam(value = "examTypeId", required = false) Long examTypeId,
                           @RequestParam(value = "courseCode", required = false) String courseCode) {
        return ResultUtil.ok(examAssignService.contrast(semesterId, examTypeId, courseCode));
    }
}
